Simulator
---------


Simulator Classes
^^^^^^^^^^^^^^^^^^

Defines a hierarchy of simulator classes

.. automodule:: stochastic_matching.simulator.classes
    :members:

Greedy tools
^^^^^^^^^^^^^

Defines functions used by greedy simulators.

.. automodule:: stochastic_matching.simulator.greedy
    :members:

Virtual Queue tools
^^^^^^^^^^^^^^^^^^^

Defines functions used by virtual queue simulator.

.. automodule:: stochastic_matching.simulator.virtual_queue
    :members:

Common
^^^^^^^

Defines various functions used by simulators

.. automodule:: stochastic_matching.simulator.common
    :members:
